@@ -23,6 +23,9 @@
  */
 package org.kohsuke.accmod.impl;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
+import java.nio.charset.StandardCharsets;
 import java.util.HashSet;
 import java.util.Set;
 import org.apache.maven.plugin.logging.Log;
@@ -85,7 +88,7 @@ public class Checker {
      * <li>internal name of a type + '.' + method name + method descriptor
      * </ul>
      */
-    private final Map<String,Restrictions> restrictions = new HashMap<String,Restrictions>();
+    private final Map<String,Restrictions> restrictions = new HashMap<>();
 
     private final AccessRestrictionFactory factory;
 
@@ -93,6 +96,7 @@ public class Checker {
 
     private int line;
 
+    @SuppressFBWarnings("EI_EXPOSE_REP2")
     public Checker(ClassLoader dependencies, ErrorListener errorListener, Properties properties,
             Log log) throws IOException {
         this.dependencies = dependencies;
@@ -146,12 +150,11 @@ public class Checker {
      *
      * @param isInTheInspectedModule
      *      This value shows up in {@link RestrictedElement#isInTheInspectedModule()}.
-     * @param stream
      */
     public void loadRestrictions(InputStream stream, final boolean isInTheInspectedModule) throws IOException {
         if (stream==null)      return;
 
-        BufferedReader r = new BufferedReader(new InputStreamReader(stream, "UTF-8"));
+        BufferedReader r = new BufferedReader(new InputStreamReader(stream, StandardCharsets.UTF_8));
         String className;
         while ((className=r.readLine())!=null) {
             InputStream is = dependencies.getResourceAsStream(className.replace('.','/') + ".class");
@@ -200,10 +203,12 @@ public class Checker {
                     private AnnotationVisitor onAnnotationFor(final String keyName, String desc) {
                         if (RESTRICTED_DESCRIPTOR.equals(desc)) {
                             RestrictedElement target = new RestrictedElement() {
+                                @Override
                                 public boolean isInTheInspectedModule() {
                                     return isInTheInspectedModule;
                                 }
 
+                                @Override
                                 public String toString() { return keyName; }
                             };
                             return new Parser(target) {
@@ -211,11 +216,7 @@ public class Checker {
                                 public void visitEnd() {
                                     try {
                                         restrictions.put(keyName,build(factory));
-                                    } catch (ClassNotFoundException e) {
-                                        failure(e);
-                                    } catch (InstantiationException e) {
-                                        failure(e);
-                                    } catch (IllegalAccessException e) {
+                                    } catch (ClassNotFoundException | IllegalAccessException | InstantiationException e) {
                                         failure(e);
                                     }
                                 }
@@ -241,12 +242,9 @@ public class Checker {
      * Inspects a class for the restriction violations.
      */
     public void checkClass(File clazz) throws IOException {
-        FileInputStream in = new FileInputStream(clazz);
-        try {
+        try (FileInputStream in = new FileInputStream(clazz)) {
             ClassReader cr = new ClassReader(in);
             cr.accept(new RestrictedClassVisitor(), SKIP_FRAMES);
-        } finally {
-            in.close();
         }
     }
 
@@ -359,26 +357,32 @@ public class Checker {
          * Constant that represents the current location.
          */
         private final Location currentLocation = new Location() {
+            @Override
             public String getClassName() {
                 return className.replace('/','.');
             }
 
+            @Override
             public String getMethodName() {
                 return methodName;
             }
 
+            @Override
             public String getMethodDescriptor() {
                 return methodDesc;
             }
 
+            @Override
             public int getLineNumber() {
                 return line;
             }
 
+            @Override
             public String toString() {
                 return className+':'+line;
             }
 
+            @Override
             public ClassLoader getDependencyClassLoader() {
                 return dependencies;
             }
@@ -429,6 +433,7 @@ public class Checker {
             line = _line;
         }
 
+        @Override
         public void visitTypeInsn(int opcode, String type) {
             switch (opcode) {
             case Opcodes.NEW:
